@@ -1,4 +1,4 @@
-#![feature(io, path, env, core, fs, process, old_path)]
+#![feature(io, path, env, core, fs, process)]
 
 extern crate "pkg-config" as pkg_config;
 
@@ -124,7 +124,5 @@ fn which(cmd: &str) -> Option<PathBuf> {
     let cmd = format!("{}{}", cmd, env::consts::EXE_SUFFIX);
     env::split_paths(&env::var("PATH").unwrap()).map(|p| {
         p.join(&cmd)
-    }).map(|p| {
-        PathBuf::new(p.as_str().unwrap())
     }).find(|p| p.exists())
 }
